@@ -1,9 +1,10 @@
 package Mail::Toaster::Logs;
 
-our $VERSION = '5.25';
-
 use strict;
 use warnings;
+
+our $VERSION = '5.25';
+
 # the output of warnings and diagnostics should not be enabled in production.
 # the SNMP daemon depends on the output of maillogs, so we need to return
 # nothing or valid counters.
@@ -70,16 +71,16 @@ sub report_yesterdays_activity {
 #        return;
 #    };
 
-    my $log = $self->get_yesterdays_send_log();
-    if ( ! -s $log ) {
+    my $send_log = $self->get_yesterdays_send_log();
+    if ( ! -s $send_log ) {
         carp "no send log file for yesterday found!\n";
         return;
     };
 
-    $log->audit( "processing log: $log" );
+    $log->audit( "processing log: $send_log" );
 
-    my $cat = $log =~ m/\.bz2$/ ? $util->find_bin( "bzcat" )
-            : $log =~ m/\.gz$/  ? $util->find_bin( "gzcat" )
+    my $cat = $send_log =~ m/\.bz2$/ ? $util->find_bin( "bzcat" )
+            : $send_log =~ m/\.gz$/  ? $util->find_bin( "gzcat" )
             : $util->find_bin( "cat" );
 
     my %cmds = (
@@ -89,14 +90,14 @@ sub report_yesterdays_activity {
     );
 
     foreach ( keys %cmds ) {
-        my $cmd = "$cat $log | $qma_dir/matchup 5>/dev/null | " . $cmds{$_}->{'cmd'};
+        my $cmd = "$cat $send_log | $qma_dir/matchup 5>/dev/null | " . $cmds{$_}->{'cmd'};
         $log->audit( "calculating $_ stats with: $cmd");
-        $cmds{'out'} = `$cmd`;
+        $cmds{$_}{'out'} = `$cmd`;
     };
 
     my ( $dd, $mm, $yy ) = $util->get_the_date(bump=>0);
     my $date = "$yy.$mm.$dd";
-    $log->date( "date: $yy.$mm.$dd" );
+    $log->audit( "date: $yy.$mm.$dd" );
 
     ## no critic
     open my $EMAIL, "| /var/qmail/bin/qmail-inject";
@@ -296,7 +297,7 @@ sub parse_cmdline_flags {
     my $debug = $self->{'debug'};
 
     my %p = validate(@_, {
-        'prot' => { type=>SCALAR, optional=>1, },
+        'prot' => { type=>SCALAR|UNDEF, optional=>1, },
         %std_opts,
     } );
 
@@ -833,7 +834,10 @@ sub spama_count {
     my %temp = ( spam => 1, ham => 1 );
 
     foreach (@$logfiles) {
-        open my $LOGF, "<", $_;
+        open my $LOGF, "<", $_ or do {
+            carp "unable to open $_: $!";
+            next;
+        };
 
         while ( my $line = <$LOGF> ) {
             next unless $line =~ /spamd/;
@@ -1468,20 +1472,12 @@ sub counter_create {
 };
 
 sub counter_read {
-
     my $self  = shift;
-    my $debug = $self->{'debug'};
-
-    my %p = validate(@_, { 
-            'file' => SCALAR, 
-            'debug' => {type=>BOOLEAN, optional=>1, default=>$debug},
-        } 
-    );
+    my %p = validate(@_, { 'file' => SCALAR, %std_opts } );
+    my %args = $log->get_std_args( %p );
 
     my $file  = $p{'file'} or croak "you must pass a filename!\n";
-       $debug = $p{'debug'};
-
-    print "counter_read: fetching counters from $file..." if $debug;
+    my $debug = $p{'debug'};
 
     if ( ! -e $file ) {
         $self->counter_create( $file ) or return;
@@ -1494,36 +1490,32 @@ sub counter_read {
         $hash{ $description } = $count;
     }
 
-    print "done.\n" if $debug;
+    $log->audit( "counter_read: read counters from $file", %args );
 
     return \%hash;
 }
 
 sub counter_write {
-
     my $self  = shift;
-    my $debug = $self->{'debug'};
-    
     my %p = validate( @_, {
             'values' => HASHREF,
             'log'    => SCALAR,
-            'fatal'  => { type=>BOOLEAN, optional=>1, default=>1 },
-            'debug'  => { type=>BOOLEAN, optional=>1, default=>$debug },
+            %std_opts,
         },
     );
+    my %args = $log->get_std_args( %p );
 
-    $debug = $p{'debug'};
-    my ( $log, $values_ref, $fatal ) = ( $p{'log'}, $p{'values'}, $p{'fatal'} );
+    my ( $logfile, $values_ref ) = ( $p{'log'}, $p{'values'} );
 
-    if ( -d $log ) { 
-        print "FAILURE: counter_write $log is a directory!\n"; 
+    if ( -d $logfile ) { 
+        print "FAILURE: counter_write $logfile is a directory!\n"; 
     }
 
-    return $log->error( "counter_write: $log is not writable",fatal=>0 )
-        unless $util->is_writable( $log, debug => 0, fatal=>$fatal );
+    return $log->error( "counter_write: $logfile is not writable",fatal=>0 )
+        unless $util->is_writable( $logfile, %args  );
 
-    unless ( -e $log ) {
-        print "NOTICE: counter_write is creating $log";
+    unless ( -e $logfile ) {
+        print "NOTICE: counter_write is creating $logfile";
     }
 
     # it might be necessary to wrap the counters
@@ -1534,7 +1526,7 @@ sub counter_write {
 
     my @lines;
     while ( my ($key, $value) = each %$values_ref ) {
-        print "key: $key  \t val: $value \n" if $debug;
+        $log->audit( "key: $key  \t val: $value", %args);
         if ( $key && defined $value ) {
             # 32 bit - 4294967295
             # 64 bit - 18446744073709551615
@@ -1543,16 +1535,7 @@ sub counter_write {
         }
     }
 
-    if ($debug) {
-        #require Data::Dumper;
-        #print Data::Dumper::Dumper ($values_ref); 
-    };
-
-    return $util->file_write( $log, 
-        lines => \@lines, 
-        debug => $debug,
-        fatal => $fatal,
-    );
+    return $util->file_write( $logfile, lines => \@lines, %args );
 }
 
 sub get_cronolog_handle {
